@@ -13,6 +13,7 @@ from .account import OPAccount, OPAccountList
 from .op_cli_version import DOCUMENT_BYTES_BUG_VERSION, OPCLIVersion
 from .py_op_exceptions import (
     OPCmdFailedException,
+    OPDocumentDeleteException,
     OPDocumentGetException,
     OPGroupGetException,
     OPGroupListException,
@@ -99,8 +100,11 @@ class _OPCommandInterface(_OPCLIExecute):
             existing_auth, password, password_prompt)
         self._signed_in_account: OPAccount = account_obj
         self._token = token
-        self.logger.debug(
-            f"Signed in as User ID: {self._signed_in_account.user_uuid}")
+        if self._signed_in_account.is_service_account():
+            self.logger.debug("Signed in as a service account")
+        else:
+            self.logger.debug(
+                f"Signed in as User ID: {self._signed_in_account.user_uuid}")
         # export OP_SESSION_<use_id>
         if self.token:
             if not self._account_identifier:
@@ -342,13 +346,26 @@ class _OPCommandInterface(_OPCLIExecute):
             self.op_path, item_name_or_id, vault=vault_arg)
         return lookup_argv
 
-    def _get_document_argv(self, document_name_or_id: str, vault: Optional[str] = None):
+    def _document_get_argv(self,
+                           document_name_or_id: str,
+                           vault: Optional[str] = None,
+                           include_archive: Optional[bool] = False):
+        vault_arg = vault if vault else self.vault
+        document_get_argv = _OPArgv.document_get_argv(self.op_path,
+                                                      document_name_or_id,
+                                                      vault=vault_arg,
+                                                      include_archive=include_archive)
+        print(document_get_argv)
+
+        return document_get_argv
+
+    def _document_delete_argv(self, document_name_or_id: str, vault: Optional[str] = None, archive=False):
         vault_arg = vault if vault else self.vault
 
-        get_document_argv = _OPArgv.document_get_argv(
-            self.op_path, document_name_or_id, vault=vault_arg)
+        document_delete_argv = _OPArgv.document_delete_argv(
+            self.op_path, document_name_or_id, vault=vault_arg, archive=archive)
 
-        return get_document_argv
+        return document_delete_argv
 
     def _user_get_argv(self, user_name_or_id: str):
         get_user_argv = _OPArgv.user_get_argv(self.op_path, user_name_or_id)
@@ -414,7 +431,10 @@ class _OPCommandInterface(_OPCLIExecute):
 
         return output
 
-    def _document_get(self, document_name_or_id: str, vault: Optional[str] = None):
+    def _document_get(self,
+                      document_name_or_id: str,
+                      vault: Optional[str] = None,
+                      include_archive: Optional[bool] = False):
         """
         Download a document object from a 1Password vault by name or UUID.
 
@@ -427,8 +447,8 @@ class _OPCommandInterface(_OPCLIExecute):
             - Bytes: document bytes
         """
 
-        get_document_argv = self._get_document_argv(
-            document_name_or_id, vault=vault)
+        get_document_argv = self._document_get_argv(
+            document_name_or_id, vault=vault, include_archive=include_archive)
 
         try:
             document_bytes = self._run(get_document_argv, capture_stdout=True)
@@ -440,10 +460,22 @@ class _OPCommandInterface(_OPCLIExecute):
             # trim it off if its present
             if document_bytes[-1] == 0x0a:
                 document_bytes = document_bytes[:-1]
-        else:
-            print(self._cli_version)
+
         return document_bytes
 
+    def _document_delete(self, document_name_or_id: str, vault: Optional[str] = None, archive=False):
+
+        document_delete_argv = self._document_delete_argv(
+            document_name_or_id, vault=vault, archive=archive)
+        try:
+            # 'op document delete' doesn't have any output if successful
+            # if it fails, stderr will be in the exception object
+            self._run(document_delete_argv)
+        except OPCmdFailedException as ocfe:
+            raise OPDocumentDeleteException.from_opexception(ocfe)
+
+        return
+
     @classmethod
     def _signed_in_accounts(cls, op_path, decode="utf-8"):
         account_list_argv = cls._account_list_argv(op_path, encoding=decode)
